@@ -74,6 +74,3 @@ class Catalog():
             usage: addCatalogRows([ { "id":42, "col_a":"a" }, { "id":24, "col_b":"b" } ])
         """
         return self.api._post("/%s" % (self.catalogName), values)
-
-def toto():
-    pass
\ No newline at end of file
